package com.ruoyi.care.service;

import java.util.List;
import com.ruoyi.care.domain.CareApplications;

/**
 * 护理申请Service接口
 * 
 * @author qy
 * @date 2024-11-25
 */
public interface ICareApplicationsService 
{
    /**
     * 查询护理申请
     * 
     * @param applyId 护理申请主键
     * @return 护理申请
     */
    public CareApplications selectCareApplicationsByApplyId(Long applyId);

    /**
     * 查询护理申请列表
     * 
     * @param careApplications 护理申请
     * @return 护理申请集合
     */
    public List<CareApplications> selectCareApplicationsList(CareApplications careApplications);

    /**
     * 新增护理申请
     * 
     * @param careApplications 护理申请
     * @return 结果
     */
    public int insertCareApplications(CareApplications careApplications);

    /**
     * 修改护理申请
     * 
     * @param careApplications 护理申请
     * @return 结果
     */
    public int updateCareApplications(CareApplications careApplications);

    /**
     * 批量删除护理申请
     * 
     * @param applyIds 需要删除的护理申请主键集合
     * @return 结果
     */
    public int deleteCareApplicationsByApplyIds(Long[] applyIds);

    /**
     * 删除护理申请信息
     * 
     * @param applyId 护理申请主键
     * @return 结果
     */
    public int deleteCareApplicationsByApplyId(Long applyId);

    /*
        指派
     */
    public int assign(CareApplications careApplications);
}
